@@ -312,6 +312,7 @@ public class HomeXMLExporter extends ObjectXMLExporter<Home> {
             if (camera instanceof ObserverCamera) {
               writer.writeBooleanAttribute("fixedSize", ((ObserverCamera)camera).isFixedSize(), false);
             }
+            writer.writeAttribute("renderer", camera.getRenderer(), null);
           }
 
           @Override
@@ -385,7 +386,7 @@ public class HomeXMLExporter extends ObjectXMLExporter<Home> {
       writer.writeFloatAttribute("depthInPlan", piece.getDepthInPlan(), piece.getDepth());
       writer.writeFloatAttribute("height", piece.getHeight());
       writer.writeFloatAttribute("heightInPlan", piece.getHeightInPlan(), piece.getHeight());
-      writer.writeBooleanAttribute("backFaceShown", piece.isBackFaceShown(), false);
+      writer.writeIntegerAttribute("modelFlags", piece.getModelFlags(), 0);
       writer.writeBooleanAttribute("modelMirrored", piece.isModelMirrored(), false);
       writer.writeBooleanAttribute("visible", piece.isVisible(), true);
       writer.writeColorAttribute("color", piece.getColor());
@@ -467,6 +468,11 @@ public class HomeXMLExporter extends ObjectXMLExporter<Home> {
           writer.writeFloatAttribute("diameter", lightSource.getDiameter());
           writer.writeEndElement();
         }
+        for (String lightSourceMaterialName : ((HomeLight)piece).getLightSourceMaterialNames()) {
+          writer.writeStartElement("lightSourceMaterial");
+          writer.writeAttribute("name", lightSourceMaterialName);
+          writer.writeEndElement();
+        }
       } else if (piece instanceof HomeDoorOrWindow) {
         for (Sash sash : ((HomeDoorOrWindow)piece).getSashes()) {
           writer.writeStartElement("sash");
@@ -607,6 +613,7 @@ public class HomeXMLExporter extends ObjectXMLExporter<Home> {
           writer.writeBooleanAttribute("ceilingVisible", room.isCeilingVisible(), true);
           writer.writeColorAttribute("ceilingColor", room.getCeilingColor());
           writer.writeFloatAttribute("ceilingShininess", room.getCeilingShininess(), 0);
+          writer.writeBooleanAttribute("ceilingFlat", room.isCeilingFlat(), false);
         }
 
         @Override
@@ -793,6 +800,7 @@ public class HomeXMLExporter extends ObjectXMLExporter<Home> {
             writer.writeFloatAttribute("yOffset", texture.getYOffset(), 0f);
             writer.writeFloatAttribute("angle", texture.getAngle(), 0f);
             writer.writeFloatAttribute("scale", texture.getScale(), 1f);
+            writer.writeBooleanAttribute("fittingArea", texture.isFittingArea(), false);
             writer.writeBooleanAttribute("leftToRightOriented", texture.isLeftToRightOriented(), true);
             writer.writeAttribute("image", getExportedContentName(texture, texture.getImage()), null);
           }
