@@ -164,7 +164,8 @@ import com.eteks.sweethome3d.tools.URLContent;
  *       yaw CDATA #REQUIRED
  *       pitch CDATA #REQUIRED
  *       time CDATA #IMPLIED
- *       fieldOfView CDATA #REQUIRED'>
+ *       fieldOfView CDATA #REQUIRED
+ *       renderer CADATA #IMPLIED'>
  *
  * &lt;!ELEMENT camera (property*)>
  * &lt;!ATTLIST camera
@@ -231,6 +232,7 @@ import com.eteks.sweethome3d.tools.URLContent;
  *       modelRotation CDATA "1 0 0 0 1 0 0 0 1"
  *       modelCenteredAtOrigin CDATA #IMPLIED
  *       backFaceShown (false | true) "false"
+ *       modelFlags CDATA #IMPLIED
  *       modelSize CDATA #IMPLIED
  *       doorOrWindow (false | true) "false"
  *       resizable (false | true) "true"
@@ -280,7 +282,7 @@ import com.eteks.sweethome3d.tools.URLContent;
  *       startAngle CDATA #REQUIRED
  *       endAngle CDATA #REQUIRED>
  *
- * &lt;!ELEMENT light (lightSource*, property*, textStyle?, texture?, material*, transformation*)>
+ * &lt;!ELEMENT light (lightSource*, lightSourceMaterial*, property*, textStyle?, texture?, material*, transformation*)>
  * &lt;!ATTLIST light
  *       %furnitureCommonAttributes;
  *       %pieceOfFurnitureCommonAttributes;
@@ -295,6 +297,10 @@ import com.eteks.sweethome3d.tools.URLContent;
  *       color CDATA #REQUIRED
  *       diameter CDATA #IMPLIED>
  *
+ * &lt;!ELEMENT lightSourceMaterial EMPTY>
+ * &lt;!ATTLIST lightSourceMaterial
+ *       name #REQUIRED>
+ *
  * &lt;!ELEMENT textStyle EMPTY>
  * &lt;!ATTLIST textStyle
  *       attribute (nameStyle | areaStyle | lengthStyle) #IMPLIED
@@ -316,6 +322,7 @@ import com.eteks.sweethome3d.tools.URLContent;
  *       angle CDATA "0"
  *       scale CDATA "1"
  *       creator CDATA #IMPLIED
+ *       fittingArea (false | true) "false"
  *       leftToRightOriented (true | false) "true"
  *       image CDATA #REQUIRED>
  *
@@ -376,7 +383,8 @@ import com.eteks.sweethome3d.tools.URLContent;
  *       floorShininess CDATA "0"
  *       ceilingVisible (false | true) "true"
  *       ceilingColor CDATA #IMPLIED
- *       ceilingShininess CDATA "0">
+ *       ceilingShininess CDATA "0"
+ *       ceilingFlat (false | true) "false">
  *
  * &lt;!ELEMENT point EMPTY>
  * &lt;!ATTLIST point
@@ -454,6 +462,7 @@ public class HomeXMLHandler extends DefaultHandler {
   private HomeTexture materialTexture;
   private final List<Sash>         sashes = new ArrayList<Sash>();
   private final List<LightSource>  lightSources = new ArrayList<LightSource>();
+  private final List<String>       lightSourceMaterialNames = new ArrayList<String>();
   private final List<float[]>      points = new ArrayList<float[]>();
   private final List<HomePieceOfFurniture.SortableProperty> furnitureVisibleProperties = new ArrayList<HomePieceOfFurniture.SortableProperty>();
 
@@ -517,6 +526,7 @@ public class HomeXMLHandler extends DefaultHandler {
       this.transformations.clear();
       this.sashes.clear();
       this.lightSources.clear();
+      this.lightSourceMaterialNames.clear();
       if ("furnitureGroup".equals(name)) {
         this.groupsFurniture.push(new ArrayList<HomePieceOfFurniture>());
       }
@@ -729,9 +739,11 @@ public class HomeXMLHandler extends DefaultHandler {
           parseOptionalColor(attributesMap, "color"),
           parseOptionalFloat(attributesMap, "diameter"));
       this.lightSources.add((LightSource)resolveObject(lightSource, name, attributesMap));
+    } else if ("lightSourceMaterial".equals(name)) {
+      this.lightSourceMaterialNames.add(attributesMap.get("name"));
     } else if ("backgroundImage".equals(name)) {
       BackgroundImage backgroundImage = new BackgroundImage(
-          parseContent(attributesMap.get("image"), null, false),
+          parseContent(name, attributesMap, "image"),
           parseFloat(attributesMap, "scaleDistance"),
           parseFloat(attributesMap, "scaleDistanceXStart"),
           parseFloat(attributesMap, "scaleDistanceYStart"),
@@ -1063,6 +1075,7 @@ public class HomeXMLHandler extends DefaultHandler {
     }
 
     camera.setName(attributes.get("name"));
+    camera.setRenderer(attributes.get("renderer"));
   }
 
   /**
@@ -1138,14 +1151,19 @@ public class HomeXMLHandler extends DefaultHandler {
     String information = attributes.get("information");
     Long creationDate = parseOptionalLong(attributes, "creationDate");
     Float grade = parseOptionalFloat(attributes, "grade");
-    Content icon = parseContent(attributes.get("icon"), catalogId, false);
-    Content planIcon = parseContent(attributes.get("planIcon"), catalogId, false);
-    Content model = parseContent(attributes.get("model"), catalogId, false);
+    Content icon = parseContent(elementName, attributes, "icon");
+    Content planIcon = parseContent(elementName, attributes, "planIcon");
+    Content model = parseContent(elementName, attributes, "model");
     float width = parseFloat(attributes, "width");
     float depth = parseFloat(attributes, "depth");
     float height = parseFloat(attributes, "height");
     boolean movable = !"false".equals(attributes.get("movable"));
-    boolean backFaceShown = "true".equals(attributes.get("backFaceShown"));
+    Integer modelFlags = parseOptionalInteger(attributes, "modelFlags");
+    if (modelFlags == null) {
+      modelFlags = "true".equals(attributes.get("backFaceShown"))
+          ? PieceOfFurniture.SHOW_BACK_FACE
+          : 0;
+    }
     Long modelSize = parseOptionalLong(attributes, "modelSize");
     String creator = attributes.get("creator");
     boolean resizable = !"false".equals(attributes.get("resizable"));
@@ -1176,8 +1194,8 @@ public class HomeXMLHandler extends DefaultHandler {
           creationDate, grade, icon, planIcon, model, width, depth, height, elevation, dropOnTopElevation, movable,
           cutOutShape, wallThickness, wallDistance, wallCutOutOnBothSides, widthDepthDeformable,
           this.sashes.toArray(new Sash [this.sashes.size()]),
-          modelRotation, backFaceShown, modelSize, creator,
-          resizable, deformable, texturable, price, valueAddedTaxPercentage, currency);
+          modelRotation, modelFlags, modelSize, creator,
+          resizable, deformable, texturable, price, valueAddedTaxPercentage, currency, null);
       piece = id != null
           ? new HomeDoorOrWindow(id, catalogDoorOrWindow)
           : new HomeDoorOrWindow(catalogDoorOrWindow);
@@ -1188,16 +1206,17 @@ public class HomeXMLHandler extends DefaultHandler {
         CatalogLight catalogLight = new CatalogLight(catalogId, name, description, information, tags, creationDate, grade,
             icon, planIcon, model, width, depth, height, elevation, dropOnTopElevation, movable,
             this.lightSources.toArray(new LightSource [this.lightSources.size()]),
-            staircaseCutOutShape, modelRotation, backFaceShown, modelSize, creator, resizable, deformable, texturable,
-            horizontallyRotatable, price, valueAddedTaxPercentage, currency);
+            this.lightSourceMaterialNames.toArray(new String [this.lightSourceMaterialNames.size()]),
+            staircaseCutOutShape, modelRotation, modelFlags, modelSize, creator, resizable, deformable, texturable,
+            horizontallyRotatable, price, valueAddedTaxPercentage, currency, null);
         piece = id != null
             ? new HomeLight(id, catalogLight)
             : new HomeLight(catalogLight);
       } else {
         CatalogPieceOfFurniture catalogPiece = new CatalogPieceOfFurniture(catalogId, name, description, information, tags,
             creationDate, grade, icon, planIcon, model, width, depth, height, elevation, dropOnTopElevation, movable,
-            staircaseCutOutShape, modelRotation, backFaceShown, modelSize, creator, resizable, deformable, texturable,
-            horizontallyRotatable, price, valueAddedTaxPercentage, currency);
+            staircaseCutOutShape, modelRotation, modelFlags, modelSize, creator, resizable, deformable, texturable,
+            horizontallyRotatable, price, valueAddedTaxPercentage, currency, null);
         piece = id != null
             ? new HomePieceOfFurniture(id, catalogPiece)
             : new HomePieceOfFurniture(catalogPiece);
@@ -1461,6 +1480,7 @@ public class HomeXMLHandler extends DefaultHandler {
     if (ceilingShininess != null) {
       room.setCeilingShininess(ceilingShininess);
     }
+    room.setCeilingFlat("true".equals(attributes.get("ceilingFlat")));
   }
 
   /**
@@ -1665,7 +1685,7 @@ public class HomeXMLHandler extends DefaultHandler {
     String catalogId = attributes.get("catalogId");
     HomeTexture texture = new HomeTexture(new CatalogTexture(catalogId,
                                attributes.get("name"),
-                               parseContent(attributes.get("image"), catalogId, true),
+                               parseContent(elementName, attributes, "image"),
                                parseFloat(attributes, "width"),
                                parseFloat(attributes, "height"),
                                attributes.get("creator")),
@@ -1680,7 +1700,8 @@ public class HomeXMLHandler extends DefaultHandler {
             : 0,
         attributes.get("scale") != null
             ? parseFloat(attributes, "scale")
-            : 1,
+                : 1,
+        "true".equals(attributes.get("fittingArea")),
         !"false".equals(attributes.get("leftToRightOriented")));
     return (HomeTexture)resolveObject(texture, elementName, attributes);
   }
@@ -1791,9 +1812,10 @@ public class HomeXMLHandler extends DefaultHandler {
   }
 
   /**
-   * Returns the content object matching the given string.
+   * Returns the content object matching the attribute named <code>attributeName</code> in the given element.
    */
-  private Content parseContent(String contentFile, String catalogId, boolean textureId) throws SAXException {
+  protected Content parseContent(String elementName, Map<String, String> attributes, String attributeName) throws SAXException {
+    String contentFile = attributes.get(attributeName);
     if (contentFile != null) {
       try {
         return new URLContent(new URL(contentFile));
@@ -1804,34 +1826,40 @@ public class HomeXMLHandler extends DefaultHandler {
           } catch (IOException ex2) {
             throw new SAXException("Invalid content " + contentFile, ex2);
           }
-        } else if (catalogId != null && this.preferences != null) {
-          // Try to find a resource matching contentFile among catalogs
-          if (textureId) {
-            for (TexturesCategory category : this.preferences.getTexturesCatalog().getCategories()) {
-              for (CatalogTexture texture : category.getTextures()) {
-                if (catalogId.equals(texture.getId())
-                    && isSameContent(contentFile, texture.getIcon())) {
-                  return texture.getIcon();
+        } else {
+          String catalogId = attributes.get("catalogId");
+          if (catalogId != null && this.preferences != null) {
+            // Try to find a resource matching contentFile among catalogs
+            if ("image".equals(attributeName)) {
+              for (TexturesCategory category : this.preferences.getTexturesCatalog().getCategories()) {
+                for (CatalogTexture texture : category.getTextures()) {
+                  if (catalogId.equals(texture.getId())
+                      && isSameContent(contentFile, texture.getIcon())) {
+                    return texture.getIcon();
+                  }
                 }
               }
-            }
-          } else {
-            for (FurnitureCategory category : this.preferences.getFurnitureCatalog().getCategories()) {
-              for (CatalogPieceOfFurniture piece : category.getFurniture()) {
-                if (catalogId.equals(piece.getId())) {
-                  if (isSameContent(contentFile, piece.getIcon())) {
-                    return piece.getIcon();
-                  } else if (isSameContent(contentFile, piece.getPlanIcon())) {
-                    return piece.getPlanIcon();
-                  } else if (isSameContent(contentFile, piece.getModel())) {
-                    return piece.getModel();
+            } else {
+              for (FurnitureCategory category : this.preferences.getFurnitureCatalog().getCategories()) {
+                for (CatalogPieceOfFurniture piece : category.getFurniture()) {
+                  if (catalogId.equals(piece.getId())) {
+                    if ("icon".equals(attributeName)
+                        && isSameContent(contentFile, piece.getIcon())) {
+                      return piece.getIcon();
+                    } else if ("planIcon".equals(attributeName)
+                               && isSameContent(contentFile, piece.getPlanIcon())) {
+                      return piece.getPlanIcon();
+                    } else if ("model".equals(attributeName)
+                               && isSameContent(contentFile, piece.getModel())) {
+                      return piece.getModel();
+                    }
                   }
                 }
               }
             }
           }
+          throw new SAXException("Missing URL base", ex1);
         }
-        throw new SAXException("Missing URL base", ex1);
       }
     } else {
       return null;
