@@ -46,7 +46,7 @@ public class Home implements Serializable, Cloneable {
    * in <code>Home</code> class or in one of the classes that it uses,
    * this number is increased.
    */
-  public static final long CURRENT_VERSION = 6500;
+  public static final long CURRENT_VERSION = 7000;
 
   private static final String  HOME_TOP_CAMERA_ID         = "camera-homeTopCamera";
   private static final String  HOME_OBSERVER_CAMERA_ID    = "observerCamera-homeObserverCamera";
@@ -825,8 +825,14 @@ public class Home implements Serializable, Cloneable {
    * @param piece  the piece to remove
    */
   public void deletePieceOfFurniture(HomePieceOfFurniture piece) {
-    // Ensure selectedItems don't keep a reference to piece
+    // Ensure selectedItems don't keep a reference to piece or to a child piece
     deselectItem(piece);
+    if (piece instanceof HomeFurnitureGroup) {
+      for (HomePieceOfFurniture groupPiece : ((HomeFurnitureGroup)piece).getAllFurniture()) {
+        deselectItem(groupPiece);
+      }
+    }
+
     int index = this.furniture.indexOf(piece);
     HomeFurnitureGroup group = index == -1
         ? getPieceOfFurnitureGroup(piece, null, this.furniture)
