@@ -101,6 +101,7 @@ import com.eteks.sweethome3d.model.CatalogPieceOfFurniture;
 import com.eteks.sweethome3d.model.Content;
 import com.eteks.sweethome3d.model.HomeMaterial;
 import com.eteks.sweethome3d.model.HomePieceOfFurniture;
+import com.eteks.sweethome3d.model.PieceOfFurniture;
 import com.eteks.sweethome3d.model.Transformation;
 import com.eteks.sweethome3d.tools.OperatingSystem;
 import com.eteks.sweethome3d.tools.TemporaryURLContent;
@@ -129,6 +130,7 @@ public class ModelPreviewComponent extends JComponent {
   private boolean                 parallelProjection;
   private Object                  iconImageLock;
   private HomePieceOfFurniture    previewedPiece;
+  private HomeMaterial            pickedMaterial;
   private boolean                 internalRotationAndSize;
   private Map<Texture, Texture>   pieceTextures = new HashMap<Texture, Texture>();
 
@@ -415,18 +417,26 @@ public class ModelPreviewComponent extends JComponent {
           this.pickedTransformGroup = null;
           this.pivotCenterPixel = null;
           this.boundedPitch = true;
-          if (transformationsChangeSupported
-              && getModelNode() != null) {
+          pickedMaterial = null;
+          if (getModelNode() != null) {
             ModelManager modelManager = ModelManager.getInstance();
-            this.boundedPitch = !modelManager.containsDeformableNode(getModelNode());
+            if (transformationsChangeSupported) {
+              this.boundedPitch = !modelManager.containsDeformableNode(getModelNode());
+            }
             Canvas3D canvas = getCanvas3D();
             PickCanvas pickCanvas = new PickCanvas(canvas, getModelNode());
             pickCanvas.setMode(PickCanvas.GEOMETRY);
             pickCanvas.setShapeLocation(mouseLocation.x, mouseLocation.y);
             PickResult result = pickCanvas.pickClosest();
             if (result != null) {
+              Shape3D shape = (Shape3D)result.getNode(PickResult.SHAPE3D);
+              HomeMaterial [] materials = modelManager.getMaterials(shape);
+              if (materials.length > 0) {
+                pickedMaterial = materials [0];
+              }
               this.pickedTransformGroup = (TransformGroup)result.getNode(PickResult.TRANSFORM_GROUP);
-              if (this.pickedTransformGroup != null) {
+              if (transformationsChangeSupported
+                  && this.pickedTransformGroup != null) {
                 // The pivot node is the first sibling node which is not a transform group
                 Group group = (Group)this.pickedTransformGroup.getParent();
                 int i = group.indexOfChild(this.pickedTransformGroup) - 1;
@@ -437,7 +447,7 @@ public class ModelPreviewComponent extends JComponent {
                   Node referenceNode = group.getChild(i);
                   Point3f nodeCenter = modelManager.getCenter(referenceNode);
                   Point3f nodeCenterAtScreen = new Point3f(nodeCenter);
-                  Transform3D pivotTransform = getTransformBetweenNodes(referenceNode.getParent(), sceneTree);
+                  Transform3D pivotTransform = getTransformBetweenNodes(referenceNode.getParent(), sceneTree, false);
                   pivotTransform.transform(nodeCenterAtScreen);
                   Transform3D transformToCanvas = new Transform3D();
                   canvas.getVworldToImagePlate(transformToCanvas);
@@ -448,10 +458,6 @@ public class ModelPreviewComponent extends JComponent {
                   String transformationName = (String)this.pickedTransformGroup.getUserData();
                   this.translationFromOrigin = new Transform3D();
                   this.translationFromOrigin.setTranslation(new Vector3d(nodeCenter));
-                  Transform3D transformBetweenNodes = getTransformBetweenNodes(referenceNode.getParent(), getModelNode());
-                  transformBetweenNodes.setTranslation(new Vector3d());
-                  transformBetweenNodes.invert();
-                  this.translationFromOrigin.mul(transformBetweenNodes);
 
                   Transform3D pitchRotation = new Transform3D();
                   pitchRotation.rotX(viewPitch);
@@ -462,7 +468,9 @@ public class ModelPreviewComponent extends JComponent {
                       || transformationName.startsWith(ModelManager.RAIL_PREFIX)) {
                     Transform3D rotation = new Transform3D();
                     Vector3f nodeSize = modelManager.getSize(referenceNode);
-                    getTransformBetweenNodes(getModelRoot(referenceNode), getModelNode()).transform(nodeSize);
+                    BranchGroup modelRoot = getModelRoot(referenceNode);
+                    Transform3D transformBetweenRootAndModelNode = getTransformBetweenNodes(modelRoot, getModelNode(), true);
+                    transformBetweenRootAndModelNode.transform(nodeSize);
                     nodeSize.absolute();
 
                     Transform3D modelRotationAtScreen = new Transform3D(yawRotation);
@@ -487,7 +495,7 @@ public class ModelPreviewComponent extends JComponent {
                       if (transformationName.startsWith(ModelManager.RAIL_PREFIX)
                           ? zAxisAtScreen.x > 0
                           : zAxisAtScreen.z < 0) {
-                      rotation.rotX(Math.PI);
+                        rotation.rotX(Math.PI);
                       }
                     } else {
                       Vector3f xAxisAtScreen = new Vector3f(1, 0, 0);
@@ -500,9 +508,12 @@ public class ModelPreviewComponent extends JComponent {
                         rotation.rotY(Math.PI / 2);
                       }
                     }
+
+                    this.translationFromOrigin.mulInverse(transformBetweenRootAndModelNode);
                     this.translationFromOrigin.mul(rotation);
                   } else {
                     // Set rotation in the screen plan for mannequin or ball handling
+                    this.translationFromOrigin.mulInverse(getTransformBetweenNodes(referenceNode.getParent(), getModelNode(), true));
                     this.translationFromOrigin.mul(yawRotation);
                     this.translationFromOrigin.mul(pitchRotation);
                   }
@@ -517,15 +528,18 @@ public class ModelPreviewComponent extends JComponent {
           }
         }
 
-        private Transform3D getTransformBetweenNodes(Node node, Node parent) {
+        private Transform3D getTransformBetweenNodes(Node node, Node parent, boolean ignoreTranslation) {
           Transform3D transform = new Transform3D();
           if (node instanceof TransformGroup) {
             ((TransformGroup)node).getTransform(transform);
+            if (ignoreTranslation) {
+              transform.setTranslation(new Vector3f());
+            }
           }
           if (node != parent) {
             Node nodeParent = node.getParent();
             if (nodeParent instanceof Group) {
-              transform.mul(getTransformBetweenNodes(nodeParent, parent), transform);
+              transform.mul(getTransformBetweenNodes(nodeParent, parent, ignoreTranslation), transform);
             } else {
               throw new IllegalStateException("Can't retrieve node transform");
             }
@@ -610,7 +624,7 @@ public class ModelPreviewComponent extends JComponent {
                   {matrix [8], matrix [9], matrix [10], matrix [11]}}));
               previewedPiece.setModelTransformations(transformationsList.toArray(new Transformation [transformationsList.size()]));
             } else {
-              if (yawChangeSupported) {
+              if (yawChangeSupported && !ev.isAltDown()) {
                 // Mouse move along X axis changes yaw
                 setViewYaw(getViewYaw() - ANGLE_FACTOR * (mouseLocation.x - this.xLastMouseMove));
               }
@@ -977,6 +991,14 @@ public class ModelPreviewComponent extends JComponent {
    */
   void setModel(final Content model, final boolean backFaceShown, final float [][] modelRotation,
                 final float width, final float depth, final float height) {
+    setModel(model, backFaceShown ? PieceOfFurniture.SHOW_BACK_FACE : 0, modelRotation, width, depth, height);
+  }
+
+  /**
+   * Sets the 3D model content displayed by this component.
+   */
+  void setModel(final Content model, final int modelFlags, final float [][] modelRotation,
+                final float width, final float depth, final float height) {
     final TransformGroup modelTransformGroup = (TransformGroup)this.sceneTree.getChild(0);
     modelTransformGroup.removeAllChildren();
     this.previewedPiece = null;
@@ -994,7 +1016,9 @@ public class ModelPreviewComponent extends JComponent {
                 internalRotationAndSize = modelRotation != null;
                 previewedPiece = new HomePieceOfFurniture(
                     new CatalogPieceOfFurniture(null, null, model,
-                        size.x, size.z, size.y, 0, false, null, modelRotation, backFaceShown, 0, false));
+                        size.x, size.z, size.y,
+                        0, false, null, null,
+                        modelRotation, modelFlags, null, null, 0, 0, 1, false));
                 previewedPiece.setX(0);
                 previewedPiece.setY(0);
                 previewedPiece.setElevation(-previewedPiece.getHeight() / 2);
@@ -1030,28 +1054,28 @@ public class ModelPreviewComponent extends JComponent {
    */
   protected void setBackFaceShown(boolean backFaceShown) {
     if (this.previewedPiece != null) {
-      // Create a new piece from the existing one with an updated backFaceShown flag
-      this.previewedPiece = new HomePieceOfFurniture(
-          new CatalogPieceOfFurniture(null, null, this.previewedPiece.getModel(),
-              this.previewedPiece.getWidth(),
-              this.previewedPiece.getDepth(),
-              this.previewedPiece.getHeight(),
-              0, false, this.previewedPiece.getColor(),
-              this.previewedPiece.getModelRotation(), backFaceShown, 0, false));
-      this.previewedPiece.setX(0);
-      this.previewedPiece.setY(0);
-      this.previewedPiece.setElevation(-previewedPiece.getHeight() / 2);
+      setModelFlags((this.previewedPiece.getModelFlags() & ~PieceOfFurniture.SHOW_BACK_FACE)
+          | (backFaceShown ? PieceOfFurniture.SHOW_BACK_FACE : 0));
+    }
+  }
 
-      TransformGroup modelTransformGroup = (TransformGroup)this.sceneTree.getChild(0);
-      HomePieceOfFurniture3D piece3D = new HomePieceOfFurniture3D(previewedPiece, null, true, true);
-      if (OperatingSystem.isMacOSX()) {
-        this.pieceTextures.clear();
-        cloneTextures(piece3D, this.pieceTextures);
-      }
-      modelTransformGroup.addChild(piece3D);
-      if (modelTransformGroup.numChildren() > 1) {
-        modelTransformGroup.removeChild(0);
-      }
+  /**
+   * Sets the visibility of edge color materials of the children nodes of the displayed 3D model.
+   */
+  protected void setEdgeColorMaterialHidden(boolean edgeColorMaterialHidden) {
+    if (this.previewedPiece != null) {
+      setModelFlags((this.previewedPiece.getModelFlags() & ~PieceOfFurniture.HIDE_EDGE_COLOR_MATERIAL)
+          | (edgeColorMaterialHidden ? PieceOfFurniture.HIDE_EDGE_COLOR_MATERIAL : 0));
+    }
+  }
+
+  /**
+   * Sets the model flags of the preview piece.
+   */
+  public void setModelFlags(int modelFlags) {
+    if (this.previewedPiece != null) {
+      this.previewedPiece.setModelFlags(modelFlags);
+      getModelNode().update();
     }
   }
 
@@ -1156,14 +1180,14 @@ public class ModelPreviewComponent extends JComponent {
   /**
    * Sets the transformations applied to 3D model.
    */
-  public void setModelTranformations(Transformation [] transformations) {
+  public void setModelTransformations(Transformation [] transformations) {
     if (this.previewedPiece != null) {
       this.previewedPiece.setModelTransformations(transformations);
       getModelNode().update();
     }
   }
 
-  void resetModelTranformations() {
+  void resetModelTransformations() {
     if (this.previewedPiece != null) {
       ModelManager modelManager = ModelManager.getInstance();
       BoundingBox oldBounds = modelManager.getBounds(getModelNode());
@@ -1172,16 +1196,16 @@ public class ModelPreviewComponent extends JComponent {
       Point3d oldUpper = new Point3d();
       oldBounds.getUpper(oldUpper);
 
-      resetTranformations(getModelNode());
+      resetTransformations(getModelNode());
 
       BoundingBox newBounds = modelManager.getBounds(getModelNode());
       Point3d newLower = new Point3d();
       newBounds.getLower(newLower);
       Point3d newUpper = new Point3d();
       newBounds.getUpper(newUpper);
-      previewedPiece.setX(previewedPiece.getX() + (float)(newUpper.x + newLower.x) / 2 - (float)(oldUpper.x + oldLower.x) / 2);
-      previewedPiece.setY(previewedPiece.getY() + (float)(newUpper.z + newLower.z) / 2 - (float)(oldUpper.z + oldLower.z) / 2);
-      previewedPiece.setElevation(previewedPiece.getElevation() + (float)(newLower.y - oldLower.y));
+      this.previewedPiece.setX(this.previewedPiece.getX() + (float)(newUpper.x + newLower.x) / 2 - (float)(oldUpper.x + oldLower.x) / 2);
+      this.previewedPiece.setY(this.previewedPiece.getY() + (float)(newUpper.z + newLower.z) / 2 - (float)(oldUpper.z + oldLower.z) / 2);
+      this.previewedPiece.setElevation(this.previewedPiece.getElevation() + (float)(newLower.y - oldLower.y));
       this.previewedPiece.setWidth((float)(newUpper.x - newLower.x));
       this.previewedPiece.setDepth((float)(newUpper.z - newLower.z));
       this.previewedPiece.setHeight((float)(newUpper.y - newLower.y));
@@ -1189,7 +1213,7 @@ public class ModelPreviewComponent extends JComponent {
     }
   }
 
-  private void resetTranformations(Node node) {
+  private void resetTransformations(Node node) {
     if (node instanceof Group) {
       if (node instanceof TransformGroup
           && node.getUserData() instanceof String
@@ -1198,7 +1222,7 @@ public class ModelPreviewComponent extends JComponent {
       }
       Enumeration<?> enumeration = ((Group)node).getAllChildren();
       while (enumeration.hasMoreElements()) {
-        resetTranformations((Node)enumeration.nextElement());
+        resetTransformations((Node)enumeration.nextElement());
       }
     }
   }
@@ -1256,6 +1280,13 @@ public class ModelPreviewComponent extends JComponent {
     return this.previewedPiece.getHeight();
   }
 
+  /**
+   * Returns the material of the shape last picked by the user.
+   */
+  public HomeMaterial getPickedMaterial() {
+    return this.pickedMaterial;
+  }
+
   /**
    * Replace the textures set on <code>node</code> shapes by clones.
    */
@@ -1309,10 +1340,11 @@ public class ModelPreviewComponent extends JComponent {
           }
         }
       }
-      // Under Linux, create canvas 3D images from captures shot with Robot
-      // because handling off screen 3D images may cause some crash problems
+      // Under Linux and Windows, create canvas 3D images from captures shot with Robot
+      // because handling off screen 3D images may cause some crash problems under Linux
+      // and doesn't refresh images correctly in some cases under Windows
       Component3DManager manager3D = Component3DManager.getInstance();
-      boolean useScreenShot = OperatingSystem.isLinux() && !Boolean.getBoolean("com.eteks.sweethome3d.j3d.useOffScreen3DView")
+      boolean useScreenShot = (OperatingSystem.isLinux() || OperatingSystem.isWindows()) && !Boolean.getBoolean("com.eteks.sweethome3d.j3d.useOffScreen3DView")
           || !manager3D.isOffScreenImageSupported();
       imageWithWhiteBackgound = useScreenShot
           ? new Robot().createScreenCapture(new Rectangle(component3DOrigin, this.component3D.getSize()))
