@@ -41,7 +41,7 @@ public class URLContent implements Content {
   private static final long serialVersionUID = 1L;
 
   private URL url;
-  
+
   public URLContent(URL url) {
     this.url = url;
   }
@@ -54,12 +54,12 @@ public class URLContent implements Content {
   }
 
   /**
-   * Returns an InputStream on the URL content. 
-   * @throws IOException if URL stream can't be opened. 
+   * Returns an InputStream on the URL content.
+   * @throws IOException if URL stream can't be opened.
    */
   public InputStream openStream() throws IOException {
     URLConnection connection = getURL().openConnection();
-    if (OperatingSystem.isWindows() && isJAREntry()) {
+    if (isJAREntry()) {
       URL jarEntryURL = getJAREntryURL();
       if (jarEntryURL.getProtocol().equalsIgnoreCase("file")) {
         try {
@@ -71,9 +71,11 @@ public class URLContent implements Content {
             file = new File(jarEntryURL.getPath());
           }
           if (file.canWrite()) {
-            // Even if cache is actually not used for JAR entries of files, refuse explicitly to use 
-            // caches to be able to delete the writable files accessed with jar protocol under Windows, 
-            // as suggested in http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=6962459 
+            // Even if cache is actually not used for JAR entries of files, refuse explicitly to use
+            // caches to be able to delete the writable files accessed with jar protocol under Windows,
+            // as suggested in http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=6962459
+            // Under other systems this is also required, otherwise the opened file is not closed on a call
+            // to close() on the returned input stream, leading to resource leak when too many files are opened
             connection.setUseCaches(false);
           }
         } catch (URISyntaxException ex) {
@@ -85,18 +87,18 @@ public class URLContent implements Content {
     }
     return connection.getInputStream();
   }
-  
+
   /**
-   * Returns <code>true</code> if the URL stored by this content 
+   * Returns <code>true</code> if the URL stored by this content
    * references an entry in a JAR.
    */
   public boolean isJAREntry() {
     return "jar".equals(this.url.getProtocol());
   }
-  
+
   /**
    * Returns the URL base of a JAR entry.
-   * @throws IllegalStateException if the URL of this content 
+   * @throws IllegalStateException if the URL of this content
    *                    doesn't reference an entry in a JAR.
    */
   public URL getJAREntryURL() {
@@ -105,17 +107,17 @@ public class URLContent implements Content {
     }
     try {
       String file = this.url.getFile();
-      return new URL(file.substring(0, file.indexOf('!')));
+      return new URL(file.substring(0, file.indexOf("!/")));
     } catch (MalformedURLException ex) {
       throw new IllegalStateException("Invalid URL base for JAR entry", ex);
     }
   }
 
   /**
-   * Returns the name of a JAR entry. 
+   * Returns the name of a JAR entry.
    * If the JAR entry in the URL given at creation time was encoded in application/x-www-form-urlencoded format,
    * this method will return it unchanged and not decoded.
-   * @throws IllegalStateException if the URL of this content 
+   * @throws IllegalStateException if the URL of this content
    *                    doesn't reference an entry in a JAR URL.
    */
   public String getJAREntryName() {
@@ -123,9 +125,9 @@ public class URLContent implements Content {
       throw new IllegalStateException("Content isn't a JAR entry");
     }
     String file = this.url.getFile();
-    return file.substring(file.indexOf('!') + 2);
+    return file.substring(file.indexOf("!/") + 2);
   }
-  
+
   /**
    * Returns the size of this content.
    * @return the size of the uncompressed zip file from which this content comes if it's a JAR entry
@@ -137,7 +139,7 @@ public class URLContent implements Content {
     ZipFile zipFile = null;
     try {
       if (isJAREntry()) {
-        long size = 0; 
+        long size = 0;
         URL zipUrl = getJAREntryURL();
         if (zipUrl.getProtocol().equals("file")) {
           // Prefer to parse entries in zip files with ZipFile class because it runs much faster
@@ -151,7 +153,7 @@ public class URLContent implements Content {
             // Try other method
           }
         }
-        
+
         // Parse entries of the zipped stream
         ZipInputStream zipIn = new ZipInputStream(zipUrl.openStream());
         in = zipIn;
@@ -188,14 +190,14 @@ public class URLContent implements Content {
    * Returns the size of the data in the given input stream.
    */
   private long getSize(InputStream in) throws IOException {
-    long size = 0; 
+    long size = 0;
     byte [] bytes = new byte [8192];
     for (int length; (length = in.read(bytes)) != -1; ) {
       size += length;
     }
     return size;
   }
-  
+
   /**
    * Returns <code>true</code> if the object in parameter is an URL content
    * that references the same URL as this object.
@@ -212,7 +214,7 @@ public class URLContent implements Content {
       return false;
     }
   }
-  
+
   @Override
   public int hashCode() {
     return this.url.hashCode();
