@@ -571,7 +571,7 @@ public class HomeFurnitureController implements Controller {
         modelMaterialsController.setModelSize(firstPieceExceptGroup.getWidth(), firstPieceExceptGroup.getDepth(), firstPieceExceptGroup.getHeight());
         modelMaterialsController.setModelRotation(firstPieceExceptGroup.getModelRotation());
         modelMaterialsController.setModelTransformations(firstPieceExceptGroup.getModelTransformations());
-        modelMaterialsController.setBackFaceShown(firstPieceExceptGroup.isBackFaceShown());
+        modelMaterialsController.setModelFlags(firstPieceExceptGroup.getModelFlags());
       }
 
       boolean defaultColorsAndTextures = true;
@@ -599,7 +599,8 @@ public class HomeFurnitureController implements Controller {
 
       // Allow transformation change only on one piece at a time
       Transformation [] modelTransformations = firstPiece.getModelTransformations();
-      if (selectedFurniture.size() != 1) {
+      if (selectedFurniture.size() != 1
+          || selectedFurniture.get(0) instanceof HomeFurnitureGroup) {
         modelTransformations = null;
       } else {
         if (modelTransformations == null) {
