@@ -1,4 +1,5 @@
 /*
+
  * HomeView.java 28 oct 2008
  *
  * Sweet Home 3D, Copyright (c) 2008 Emmanuel PUYBARET / eTeks <info@eteks.com>
@@ -65,7 +66,7 @@ public interface HomeView extends View {
       DISTRIBUTE_FURNITURE_HORIZONTALLY, DISTRIBUTE_FURNITURE_VERTICALLY, RESET_FURNITURE_ELEVATION,
       GROUP_FURNITURE, UNGROUP_FURNITURE, EXPORT_TO_CSV,
       SELECT, PAN, CREATE_WALLS, CREATE_ROOMS, CREATE_DIMENSION_LINES, CREATE_POLYLINES, CREATE_LABELS, DELETE_SELECTION,
-      LOCK_BASE_PLAN, UNLOCK_BASE_PLAN, FLIP_HORIZONTALLY, FLIP_VERTICALLY,
+      LOCK_BASE_PLAN, UNLOCK_BASE_PLAN, ENABLE_MAGNETISM, DISABLE_MAGNETISM, FLIP_HORIZONTALLY, FLIP_VERTICALLY,
       MODIFY_COMPASS, MODIFY_WALL, JOIN_WALLS, REVERSE_WALL_DIRECTION, SPLIT_WALL,
       MODIFY_ROOM, ADD_ROOM_POINT, DELETE_ROOM_POINT, MODIFY_POLYLINE, MODIFY_LABEL,
       INCREASE_TEXT_SIZE, DECREASE_TEXT_SIZE, TOGGLE_BOLD_STYLE, TOGGLE_ITALIC_STYLE,
