@@ -36,6 +36,7 @@ import junit.framework.TestCase;
 
 import com.eteks.sweethome3d.io.DefaultUserPreferences;
 import com.eteks.sweethome3d.io.FileUserPreferences;
+import com.eteks.sweethome3d.j3d.PhotoRenderer;
 import com.eteks.sweethome3d.model.BackgroundImage;
 import com.eteks.sweethome3d.model.Content;
 import com.eteks.sweethome3d.model.Home;
@@ -242,6 +243,24 @@ public class UserPreferencesPanelTest extends TestCase {
         LengthUnit.INCH.getFormatWithUnit().format(LengthUnit.inchToCentimeter(-0.125f)));
     assertEquals("Wrong conversion", "-1'",
         LengthUnit.INCH.getFormatWithUnit().format(LengthUnit.inchToCentimeter(-12)));
+    assertEquals("Wrong conversion", "11\"",
+        LengthUnit.INCH_FRACTION.getFormat().format(LengthUnit.inchToCentimeter(11)));
+    assertEquals("Wrong conversion", "23\"",
+        LengthUnit.INCH_FRACTION.getFormatWithUnit().format(LengthUnit.inchToCentimeter(11 + 12)));
+    assertEquals("Wrong conversion", "23\u215b\"",
+        LengthUnit.INCH_FRACTION.getFormatWithUnit().format(LengthUnit.inchToCentimeter(11 + 12 + 0.125f)));
+    assertEquals("Wrong conversion", "-23\u215b\"",
+        LengthUnit.INCH_FRACTION.getFormatWithUnit().format(LengthUnit.inchToCentimeter(-(11 + 12 + 0.125f))));
+    assertEquals("Wrong conversion", "-11\u215b\"",
+        LengthUnit.INCH_FRACTION.getFormatWithUnit().format(LengthUnit.inchToCentimeter(-(11 + 0.125f))));
+    assertEquals("Wrong conversion", "-0\u215b\"",
+        LengthUnit.INCH_FRACTION.getFormatWithUnit().format(LengthUnit.inchToCentimeter(-0.125f)));
+    assertEquals("Wrong conversion", "-12\"",
+        LengthUnit.INCH_FRACTION.getFormatWithUnit().format(LengthUnit.inchToCentimeter(-12)));
+    assertEquals("Wrong conversion", "-12\"",
+        LengthUnit.INCH_FRACTION.getFormatWithUnit().format(LengthUnit.inchToCentimeter(-12 - 0.05f)));
+    assertEquals("Wrong conversion", "-12\"",
+        LengthUnit.INCH_FRACTION.getFormatWithUnit().format(LengthUnit.inchToCentimeter(-12 + 0.05f)));
 
     // Test formats with unit
     assertEquals("Wrong conversion", "102 cm", LengthUnit.CENTIMETER.getFormatWithUnit().format(102));
@@ -258,6 +277,8 @@ public class UserPreferencesPanelTest extends TestCase {
         LengthUnit.INCH.getFormatWithUnit().format(LengthUnit.inchToCentimeter(11 + 12)));
     assertEquals("Wrong conversion", "1'11\u215b\"",
         LengthUnit.INCH.getFormatWithUnit().format(LengthUnit.inchToCentimeter(11 + 12 + 0.125f)));
+    assertEquals("Wrong conversion", "11\"",
+        LengthUnit.INCH_FRACTION.getFormatWithUnit().format(LengthUnit.inchToCentimeter(11)));
 
     // Test parsing
     assertEquals("Wrong parsing", 102f, LengthUnit.CENTIMETER.getFormat().parseObject("102"));
@@ -267,6 +288,10 @@ public class UserPreferencesPanelTest extends TestCase {
         ((Number)LengthUnit.INCH_DECIMALS.getFormat().parseObject("0,125")).floatValue(), 1E-10f);
     assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(0.125f),
         ((Number)LengthUnit.INCH_DECIMALS.getFormat().parseObject("0,125\"")).floatValue(), 1E-10f);
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(0.125f),
+        ((Number)LengthUnit.FOOT_DECIMALS.getFormat().parseObject("0,0104167")).floatValue(), 1E-5f);
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(0.125f),
+        ((Number)LengthUnit.FOOT_DECIMALS.getFormat().parseObject("0,0104167\'")).floatValue(), 1E-5f);
     assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(11),
         ((Number)LengthUnit.INCH.getFormat().parseObject("0'11\"")).floatValue(), 1E-10f);
     assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(10 + 12),
@@ -342,6 +367,7 @@ public class UserPreferencesPanelTest extends TestCase {
    * Tests language changes on the GUI.
    */
   public void testLanguageChange() {
+    System.setProperty("com.eteks.sweethome3d.j3d.rendererClassNames", PhotoRenderer.class.getName());
     Locale defaultLocale = Locale.getDefault();
     Locale.setDefault(Locale.US);
     UserPreferences preferences = new DefaultUserPreferences() {
